<?php
namespace Model;

// Data Class

/**
 * Class User
 * 
 * Represents a user in the system
 */
class User{
    private int $id;
    private string $nom;
    private string $prenom;
    private string $username;
    private string $email;
    private string $motDePasse;
    private string $sexe;
    private float $taille;
    private float $poids;
    private \DateTime $dateNaissance;
    private Role $role;
    protected array $notifications = [];

    /**
     * @return array
     */
    public function getNotifications(): array
    {
        return $this->notifications;
    }

    /**
     * @param int $id
     * @param string $nom
     * @param string $prenom
     * @param string $username
     * @param string $email
     * @param string $motDePasse
     * @param string $sexe
     * @param float $taille
     * @param float $poids
     * @param \DateTime $dateNaissance
     * @param \Model\Role $role
     */
    public function __construct(int $id, string $nom, string $prenom, string $username, string $email, string $motDePasse, string $sexe, float $taille, float $poids, \DateTime $dateNaissance, Role $role)
    {
        $this->id = $id;
        $this->nom = $nom;
        $this->prenom = $prenom;
        $this->username = $username;
        $this->email = $email;
        $this->motDePasse = $motDePasse;
        $this->sexe = $sexe;
        $this->taille = $taille;
        $this->poids = $poids;
        $this->dateNaissance = $dateNaissance;
        $this->role = $role;
    }

    public function addNotification($notification): void {
        $this->notifications[] = $notification;
    }

    // Method to delete a notification by its index
    public function deleteNotification($index): void {
        if (array_key_exists($index, $this->notifications)) {
            unset($this->notifications[$index]);
        }
    }

    public function getId(): int {
        return $this->id;
    }
    /**
     * @return string
     */
    public function getUsername(): string
    {
        return $this->username;
    }

    /**
     * @param string $username
     */
    public function setUsername(string $username): void
    {
        $this->username = $username;
    }

    public function setId(int $id): void {
        $this->id = $id;
    }

    public function getNom(): string {
        return $this->nom;
    }

    public function setNom(string $nom): void {
        $this->nom = $nom;
    }

    public function getPrenom(): string {
        return $this->prenom;
    }

    public function setPrenom(string $prenom): void {
        $this->prenom = $prenom;
    }

    public function getEmail(): string {
        return $this->email;
    }

    public function setEmail(string $email): void {
        $this->email = $email;
    }
    
     /**
     * @return string hashed password used to authenticate the user.
     */
    public function getMotDePasse(): string {
        return $this->motDePasse;
    }

    public function setMotDePasse(string $motDePasse): void {
        $this->motDePasse = $motDePasse;
    }

    public function getSexe(): string {
        return $this->sexe;
    }

    public function setSexe(string $sexe): void {
        $this->sexe = $sexe;
    }

    public function getTaille(): float {
        return $this->taille;
    }

    public function setTaille(float $taille): void {
        $this->taille = $taille;
    }

    public function getPoids(): float {
        return $this->poids;
    }

    public function setPoids(float $poids): void {
        $this->poids = $poids;
    }

    public function getDateNaissance(): \DateTime {
        return $this->dateNaissance;
    }

    public function setDateNaissance(\DateTime $dateNaissance): void {
        $this->dateNaissance = $dateNaissance;
    }

    public function getRole(): Role {
        return $this->role;
    }

    public function setRole(Role $role): void {
        $this->role = $role;
    }

    public function isValidPassword(string $password) {
        // TODO: Not implemented Hasher le mot de passe this not the responsability of the user this is not SOLID
        return $this->motDePasse === $password;
    }

    public function __toString() {
        return "Athlete [ID: {$this->id}, Username : $this->username, Nom: {$this->nom}, Prénom: {$this->prenom}, Email: {$this->email}]";
    }
    
} 